@@ -88,6 +88,7 @@ def mmread_n_clear(  filename = MMAPFILE ):
             mmcreate(filename)
 
     if not os.path.exists(filename):
+        print( "xxxxxx ... mmapfile not found...","1")
         return  "xxxxxx","1"
 
 
@@ -104,8 +105,8 @@ def mmread_n_clear(  filename = MMAPFILE ):
                 response = text.split("*")[0]
                 response = f"{response.split()[0].strip()}",f"{response.split()[1].strip()}"
                 print("i... mmapread'nclear returning ", response)
-                print("i... mmapread'nclear returning ", response)
-                print("i... mmapread'nclear returning ", response)
+                # print("i... mmapread'nclear returning ", response)
+                # print("i... mmapread'nclear returning ", response)
 
             text = "*"*50
             # print("CLEARING: ",text)
