@@ -79,7 +79,7 @@ class Camera(BaseCamera):
             pixelformat = "YUYV" # I use lossless format for camera readout
 
             w,h =  int(res.split("x")[0]), int(res.split("x")[1])
-            fourcc = cv2.VideoWriter_fourcc(*pixelformat)
+            fourcc = cv2.VideoWriter_fourcc(*pixelformat) # for capture device
             cap.set(cv2.CAP_PROP_FOURCC, fourcc)
             print(f"i... setting RESOLUTION: {w} x {h} and PIXELFORMAT {fourcc}")
             cap.set(cv2.CAP_PROP_FRAME_WIDTH,   w )
@@ -106,6 +106,7 @@ class Camera(BaseCamera):
         global timelaps, rotate180
         global fixed_image # show not camera but image
         global zoom
+        global pausedMOTION
 
         # print("i... staticmethod frames @ real -  enterred; target_frame==", target_frame)
         senh = Stream_Enhancer()
@@ -187,6 +188,11 @@ class Camera(BaseCamera):
 
         fixed_image = None # just camera.
 
+        # --- 433MHz
+        pausedMOTION = False
+
+
+
         camera = Camera(  )
         vidnum = None # it will be re-asked gain and again
 
@@ -462,7 +468,9 @@ class Camera(BaseCamera):
                         restart_translate = False
 
 
-                    # ------------------------- commands comming from web.py----
+                    # ------------- commands comming from web.py----------------
+                    # ------------- COMMANDS COMMING FROM WEB.PY----------------
+                    # ------------- commands comming from web.py----------------
                     #           -------------- or from seread (fixed_image ...)
                     expression,value = mmread_n_clear( )
 
@@ -739,13 +747,19 @@ class Camera(BaseCamera):
                         elif (senh.jtelegram):
                             MODE_DM=MODE_DMbase+"T"
 
-                        senh.setbox(MODE_DM, senh.MODE) #---push UP to avoid DetMot
+
+                        senh.setbox(MODE_DM, senh.MODE, grayed = pausedMOTION) #---push UP to avoid DetMot
                         #print("D... detecting motion")
                         senh.detmo( average, blur)
                         senh.chk_threshold( threshold )
+                        #
+                        # I need a way to block DETMO ....
+                        # ??? BLUETOOTH ------- see later
+                        #
                         if senh.motion_detected: # saving avi on mation detect
                             # print("D... sav mot", senh.motion_detected)
-                            senh.save_avi( seconds = -1, name = "dm" )
+                            if not pausedMOTION:
+                                senh.save_avi( seconds = -1, name = "dm" )
 
                     else:
                         senh.setaccum( average  )
