@@ -294,12 +294,18 @@ def crossonw( img,  dix, diy):
 
 
 
-@auth.verify_password
+# --- probably a wrong guess ... @auth.verify_password
+# i need  @auth.login_required
 @app.route("/cross", methods=['GET', 'POST'])
+# @auth.login_required
 def cross():
     global cross_dx, cross_dy, cross_on, save_bg, save_fg, mix_fg, sub_bg, zoom2_on
-
+    global remote_ip
     # i will read it from file
+    print("i... request (authenticated) on cross came...\n ...",request.form)
+
+    remote_ip=request.environ.get('HTTP_X_REAL_IP', request.remote_addr)
+    logthis(f"  {remote_ip}/{request.remote_addr}  {request.form}")
     crocfg = os.path.expanduser("~/.config/flashcam/cross.txt")
     if os.path.exists(crocfg):
         with open(crocfg) as f:
@@ -487,11 +493,25 @@ def cross():
                 if (pantilthat.get_pan()+8)<=90:
                     pantilthat.pan( pantilthat.get_pan()+8 )
 
+        if  request.form.get('external_signal') is not None:
+            excommand = str( request.form.get('external_signal') )
+            print(f"**** external signal == {excommand} *****")
+            print(f"**** external signal == {excommand} *****")
+            print(f"**** external signal == {excommand} *****")
+            print(f"**** external signal == {excommand} *****")
+            if excommand == "pausedmON":
+                print("i... unpause   - Detect Motion")
+                mmwrite(f"pausedMOTION False" )
+            if excommand == "pausedmOF":
+                print("i... pause - NO Detect Motion NOW")
+                mmwrite(f"pausedMOTION True" )
+
+
         if  request.form.get('crosson') == 'CROSSON':
-            print("ON")
+            print("green cross ON")
             cross_on = True
         elif  request.form.get('crossoff') == 'CROSSOFF':
-            print("OFF")
+            print("green cross OFF")
             cross_on = False
 
         if  request.form.get('zoom2') == 'ZOOM2':
@@ -512,6 +532,19 @@ def cross():
                 zoom2_on = 1
                 mmwrite(f"zoom 1" )
 
+        #---------------- I am blindly adding functionality ... compression now
+        if  request.form.get('kompress') == 'KOMPRESS':
+            print("kompress asked  ....... ")
+            #kompressvalue = request.form.get('kompressvalue')
+            if config.CONFIG['kompress']>90:
+                config.CONFIG['kompress'] = 9
+                print("KOMPRESS", config.CONFIG['kompress'] )
+            else:
+                config.CONFIG['kompress'] = 99
+                print("KOMPRESS", config.CONFIG['kompress'] )
+                #mmwrite(f"zoom 2" ) # not here...
+
+
         # .... save cross x and y inside a file at ~/.config/flashcam/
         with open(crocfg,"w") as f:
             f.write(f"{cross_dx} {cross_dy}")
